@@ -1,5 +1,6 @@
 #pragma once
 #include <FileSystem.h>
+#include <ui/pages/instance/DataPackPage.h>
 #include "minecraft/MinecraftInstance.h"
 #include "ui/pages/BasePage.h"
 #include "ui/pages/BasePageProvider.h"
@@ -36,18 +37,15 @@ class InstancePageProvider : protected QObject, public BasePageProvider {
         values.append(new CoreModFolderPage(onesix.get(), onesix->coreModList()));
         values.append(new NilModFolderPage(onesix.get(), onesix->nilModList()));
         values.append(new ResourcePackPage(onesix.get(), onesix->resourcePackList()));
+        values.append(new GlobalDataPackPage(onesix.get()));
         values.append(new TexturePackPage(onesix.get(), onesix->texturePackList()));
         values.append(new ShaderPackPage(onesix.get(), onesix->shaderPackList()));
         values.append(new NotesPage(onesix.get()));
         values.append(new WorldListPage(onesix, onesix->worldList()));
         values.append(new ServersPage(onesix));
-        // values.append(new GameOptionsPage(onesix.get()));
         values.append(new ScreenshotsPage(FS::PathCombine(onesix->gameRoot(), "screenshots")));
-        values.append(new InstanceSettingsPage(onesix.get()));
-        auto logMatcher = inst->getLogFileMatcher();
-        if (logMatcher) {
-            values.append(new OtherLogsPage(inst->getLogFileRoot(), logMatcher));
-        }
+        values.append(new InstanceSettingsPage(onesix));
+        values.append(new OtherLogsPage("logs", tr("Other Logs"), "Other-Logs", inst));
         return values;
     }
 
