@@ -25,7 +25,7 @@ void LibrariesTask::executeTask()
 
     auto metacache = APPLICATION->metacache();
 
-    auto processArtifactPool = [&](const QList<LibraryPtr>& pool, QStringList& errors, const QString& localPath) {
+    auto processArtifactPool = [this, inst, metacache](const QList<LibraryPtr>& pool, QStringList& errors, const QString& localPath) {
         for (auto lib : pool) {
             if (!lib) {
                 emitFailed(tr("Null jar is specified in the metadata, aborting."));
