@@ -49,6 +49,7 @@
 #include <QtMath>
 
 #include "VisualGroup.h"
+#include "ui/themes/CatPainter.h"
 #include "ui/themes/ThemeManager.h"
 
 #include <Application.h>
@@ -78,6 +79,9 @@ InstanceView::~InstanceView()
 {
     qDeleteAll(m_groups);
     m_groups.clear();
+    if (m_cat) {
+        m_cat->deleteLater();
+    }
 }
 
 void InstanceView::setModel(QAbstractItemModel* model)
@@ -89,7 +93,7 @@ void InstanceView::setModel(QAbstractItemModel* model)
 
 void InstanceView::dataChanged([[maybe_unused]] const QModelIndex& topLeft,
                                [[maybe_unused]] const QModelIndex& bottomRight,
-                               [[maybe_unused]] const QVector<int>& roles)
+                               [[maybe_unused]] const QList<int>& roles)
 {
     scheduleDelayedItemsLayout();
 }
@@ -172,7 +176,7 @@ void InstanceView::updateScrollbar()
 
 void InstanceView::updateGeometries()
 {
-    geometryCache.clear();
+    m_geometryCache.clear();
 
     QMap<LocaleString, VisualGroup*> cats;
 
@@ -186,8 +190,8 @@ void InstanceView::updateGeometries()
                 cat->update();
             } else {
                 auto cat = new VisualGroup(groupName, this);
-                if (fVisibility) {
-                    cat->collapsed = fVisibility(groupName);
+                if (m_fVisibility) {
+                    cat->collapsed = m_fVisibility(groupName);
                 }
                 cats.insert(groupName, cat);
                 cat->update();
@@ -400,12 +404,8 @@ void InstanceView::mouseReleaseEvent(QMouseEvent* event)
         if (event->button() == Qt::LeftButton) {
             emit clicked(index);
         }
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         QStyleOptionViewItem option;
         initViewItemOption(&option);
-#else
-        QStyleOptionViewItem option = viewOptions();
-#endif
         if (m_pressedAlreadySelected) {
             option.state |= QStyle::State_Selected;
         }
@@ -422,7 +422,7 @@ void InstanceView::mouseDoubleClickEvent(QMouseEvent* event)
 
     QModelIndex index = indexAt(event->pos());
     if (!index.isValid() || !(index.flags() & Qt::ItemIsEnabled) || (m_pressedIndex != index)) {
-        QMouseEvent me(QEvent::MouseButtonPress, event->localPos(), event->windowPos(), event->screenPos(), event->button(),
+        QMouseEvent me(QEvent::MouseButtonPress, event->position(), event->scenePosition(), event->globalPosition(), event->button(),
                        event->buttons(), event->modifiers());
         mousePressEvent(&me);
         return;
@@ -431,12 +431,8 @@ void InstanceView::mouseDoubleClickEvent(QMouseEvent* event)
     QPersistentModelIndex persistent = index;
     emit doubleClicked(persistent);
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     QStyleOptionViewItem option;
     initViewItemOption(&option);
-#else
-    QStyleOptionViewItem option = viewOptions();
-#endif
     if ((model()->flags(index) & Qt::ItemIsEnabled) && !style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick, &option, this)) {
         emit activated(index);
     }
@@ -444,11 +440,15 @@ void InstanceView::mouseDoubleClickEvent(QMouseEvent* event)
 
 void InstanceView::setPaintCat(bool visible)
 {
-    m_catVisible = visible;
-    if (visible)
-        m_catPixmap.load(APPLICATION->themeManager()->getCatPack());
-    else
-        m_catPixmap = QPixmap();
+    if (m_cat) {
+        disconnect(m_cat, &CatPainter::updateFrame, this, nullptr);
+        delete m_cat;
+        m_cat = nullptr;
+    }
+    if (visible) {
+        m_cat = new CatPainter(APPLICATION->themeManager()->getCatPack(), this);
+        connect(m_cat, &CatPainter::updateFrame, this, [this] { viewport()->update(); });
+    }
 }
 
 void InstanceView::paintEvent([[maybe_unused]] QPaintEvent* event)
@@ -457,27 +457,12 @@ void InstanceView::paintEvent([[maybe_unused]] QPaintEvent* event)
 
     QPainter painter(this->viewport());
 
-    if (m_catVisible) {
-        painter.setOpacity(APPLICATION->settings()->get("CatOpacity").toFloat() / 100);
-        int widWidth = this->viewport()->width();
-        int widHeight = this->viewport()->height();
-        if (m_catPixmap.width() < widWidth)
-            widWidth = m_catPixmap.width();
-        if (m_catPixmap.height() < widHeight)
-            widHeight = m_catPixmap.height();
-        auto pixmap = m_catPixmap.scaled(widWidth, widHeight, Qt::KeepAspectRatio, Qt::SmoothTransformation);
-        QRect rectOfPixmap = pixmap.rect();
-        rectOfPixmap.moveBottomRight(this->viewport()->rect().bottomRight());
-        painter.drawPixmap(rectOfPixmap.topLeft(), pixmap);
-        painter.setOpacity(1.0);
+    if (m_cat) {
+        m_cat->paint(&painter, this->viewport()->rect());
     }
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     QStyleOptionViewItem option;
     initViewItemOption(&option);
-#else
-    QStyleOptionViewItem option = viewOptions();
-#endif
     option.widget = this;
 
     if (model()->rowCount() == 0) {
@@ -610,7 +595,7 @@ void InstanceView::dragEnterEvent(QDragEnterEvent* event)
     if (!isDragEventAccepted(event)) {
         return;
     }
-    m_lastDragPosition = event->pos() + offset();
+    m_lastDragPosition = event->position().toPoint() + offset();
     viewport()->update();
     event->accept();
 }
@@ -622,7 +607,7 @@ void InstanceView::dragMoveEvent(QDragMoveEvent* event)
     if (!isDragEventAccepted(event)) {
         return;
     }
-    m_lastDragPosition = event->pos() + offset();
+    m_lastDragPosition = event->position().toPoint() + offset();
     viewport()->update();
     event->accept();
 }
@@ -648,7 +633,7 @@ void InstanceView::dropEvent(QDropEvent* event)
 
     if (event->source() == this) {
         if (event->possibleActions() & Qt::MoveAction) {
-            std::pair<VisualGroup*, VisualGroup::HitResults> dropPos = rowDropPos(event->pos());
+            std::pair<VisualGroup*, VisualGroup::HitResults> dropPos = rowDropPos(event->position().toPoint());
             const VisualGroup* group = dropPos.first;
             auto hitResult = dropPos.second;
 
@@ -723,8 +708,8 @@ QRect InstanceView::geometryRect(const QModelIndex& index) const
     }
 
     int row = index.row();
-    if (geometryCache.contains(row)) {
-        return *geometryCache[row];
+    if (m_geometryCache.contains(row)) {
+        return *m_geometryCache[row];
     }
 
     const VisualGroup* cat = category(index);
@@ -732,18 +717,14 @@ QRect InstanceView::geometryRect(const QModelIndex& index) const
     int x = pos.first;
     // int y = pos.second;
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     QStyleOptionViewItem option;
     initViewItemOption(&option);
-#else
-    QStyleOptionViewItem option = viewOptions();
-#endif
 
     QRect out;
     out.setTop(cat->verticalPosition() + cat->headerHeight() + 5 + cat->rowTopOf(index));
     out.setLeft(m_spacing + x * (itemWidth() + m_spacing));
     out.setSize(itemDelegate()->sizeHint(option, index));
-    geometryCache.insert(row, new QRect(out));
+    m_geometryCache.insert(row, new QRect(out));
     return out;
 }
 
@@ -784,12 +765,8 @@ QPixmap InstanceView::renderToPixmap(const QModelIndexList& indices, QRect* r) c
     QPixmap pixmap(r->size());
     pixmap.fill(Qt::transparent);
     QPainter painter(&pixmap);
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     QStyleOptionViewItem option;
     initViewItemOption(&option);
-#else
-    QStyleOptionViewItem option = viewOptions();
-#endif
     option.state |= QStyle::State_Selected;
     for (int j = 0; j < paintPairs.count(); ++j) {
         option.rect = paintPairs.at(j).first.translated(-r->topLeft());
