@@ -393,9 +393,10 @@ bool NilModFolderPage::shouldDisplay() const
 // Helper function so this doesn't need to be duplicated 3 times
 inline bool ModFolderPage::handleNoModLoader()
 {
-    int resp = QMessageBox::question(this, this->tr("Missing Mod Loader"),
-                                     this->tr("You need to install a compatible mod loader before installing mods. Would you like to do so?"),
-                                     QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
+    int resp =
+        QMessageBox::question(this, this->tr("Missing Mod Loader"),
+                              this->tr("You need to install a compatible mod loader before installing mods. Would you like to do so?"),
+                              QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
     switch (resp) {
         case QMessageBox::Yes: {
             // Should be safe
@@ -403,8 +404,8 @@ inline bool ModFolderPage::handleNoModLoader()
             InstallLoaderDialog dialog(profile, QString(), this);
             bool ret = dialog.exec();
             this->m_container->refreshContainer();
-            
-            // returning negation of dialog.exec which'll be true if the install loader dialog got canceled/closed 
+
+            // returning negation of dialog.exec which'll be true if the install loader dialog got canceled/closed
             // and false if the user went through and installed a loader
             return !ret;
         }
