@@ -54,7 +54,7 @@ SystemTheme::SystemTheme(const QString& styleName, const QPalette& defaultPalett
         m_colorPalette = defaultPalette;
     } else {
         auto style = QStyleFactory::create(styleName);
-        m_colorPalette = style->standardPalette();
+        m_colorPalette = style != nullptr ? style->standardPalette() : defaultPalette;
         delete style;
     }
 }
